#
# spec file for package OpenColorIO
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2020 Asterios Dramis <asterios.dramis@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Ensure that libyaml-cpp version is the one that is built against
# See boo#1160171
%define yamlrequires %(rpm -q --requires yaml-cpp-devel | grep libyaml)
%define so_ver 1
Name:           OpenColorIO
Version:        1.1.1
Release:        bp156.3.7
Summary:        Color Management Solution Geared Towards Motion Picture Production
License:        BSD-3-Clause AND GPL-2.0-or-later
Group:          Productivity/Graphics/Other
URL:            https://opencolorio.org/
######
######
# The package contains the below non OSS licensed files (see bnc#821203)
#
# ext/Pygments-1.6/tests/examplefiles/Sorting.mod
# ext/Pygments-1.6/tests/examplefiles/test.mod
#
# so a crippled tarball is used with these files removed. Steps to reproduce:
#
# tar zxf OpenColorIO-%%{version}.tar.gz
# pushd OpenColorIO-%%{version}/ext/
# tar zxf Pygments-1.6.tar.gz
# rm -f Pygments-1.6.tar.gz
# rm -f Pygments-1.6/tests/examplefiles/{Sorting.mod,test.mod}
# tar zcf Pygments-1.6.tar.gz Pygments-1.6/
# rm -rf Pygments-1.6/
# popd
# tar zcf OpenColorIO-%%{version}-crippled.tar.gz OpenColorIO-%%{version}/
# rm -f OpenColorIO-%%{version}.tar.gz
#
# NOTE: In newer OpenColorIO versions, Pygments (version 1.6) maybe updated.
# In this case check if the above files' license is changed, so no crippled tarball is needed.
#####
#####
Source0:        %{name}-%{version}-crippled.tar.gz
# PATCH-FIX-UPSTREAM OpenColorIO-setuptools.patch asterios.dramis@gmail.com -- Use external python-setuptools for building (taken from Fedora)
Patch0:         OpenColorIO-setuptools.patch
# PATCH-FIX-UPSTREAM 0003-Fix_Linux_compilation.patch asterios.dramis@gmail.com -- Fix Linux compilation (taken from Debian)
Patch1:         0003-Fix_Linux_compilation.patch
# PATCH-FIX-UPSTREAM 0004-Fix_build_with_GCC-8.patch asterios.dramis@gmail.com -- Fix build with GCC-8 (taken from Debian)
Patch2:         0004-Fix_build_with_GCC-8.patch
# PATCH-FIX-UPSTREAM 0005-Fix_build_with_yaml-cpp0.6.patch asterios.dramis@gmail.com -- Fix build with yaml-cpp0.6 (taken from Debian)
Patch3:         0005-Fix_build_with_yaml-cpp0.6.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libboost_headers-devel
BuildRequires:  liblcms2-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-MarkupSafe
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  tinyxml-devel
BuildRequires:  pkgconfig(yaml-cpp) >= 0.5.0
Recommends:     %{name}-doc = %{version}

%description
OpenColorIO (OCIO) is a color management solution geared towards motion picture
production with an emphasis on visual effects and computer animation.

OCIO is compatible with the Academy Color Encoding Specification (ACES) and is
LUT-format agnostic, supporting many popular formats.

%package devel
Summary:        Development Files for OpenColorIO
Group:          Development/Libraries/C and C++
Requires:       libOpenColorIO%{so_ver} = %{version}
Recommends:     %{name}-doc = %{version}

%description devel
This package provides development libraries and headers needed to build
software using OpenColorIO.

%package doc
Summary:        Documentation for OpenColorIO
Group:          Documentation/Other
BuildArch:      noarch

%description doc
This package contains documentation for OpenColorIO.

%package -n libOpenColorIO%{so_ver}
Summary:        Complete Color Management Solution Geared Towards Motion Picture Production
Group:          System/Libraries
Requires:       %{yamlrequires}

%description -n libOpenColorIO%{so_ver}
OpenColorIO (OCIO) is a color management solution geared towards motion picture
production with an emphasis on visual effects and computer animation.

OCIO is compatible with the Academy Color Encoding Specification (ACES) and is
LUT-format agnostic, supporting many popular formats.

%package -n python-OpenColorIO
Summary:        Python Bindings for OpenColorIO
Group:          Development/Libraries/Python

%description -n python-OpenColorIO
This package contains python bindings for OpenColorIO.

%package -n python-OpenColorIO-devel
Summary:        Python Bindings for OpenColorIO
Group:          Development/Libraries/Python
Requires:       python-OpenColorIO = %{version}
Requires:       python3-devel

%description -n python-OpenColorIO-devel
This package contains development files for python bindings for OpenColorIO.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

# Make sure that bundled libraries are not used
rm -f ext/lcms*
rm -f ext/tinyxml*
rm -f ext/yaml*

%build
%cmake \
    -DPYTHON=%{_bindir}/python3 \
    -DOCIO_BUILD_STATIC=OFF \
    -DOCIO_BUILD_DOCS=ON \
    -DOCIO_BUILD_TESTS=ON \
    -DOCIO_PYGLUE_LINK=ON \
%ifnarch x86_64
    -DOCIO_USE_SSE=OFF \
%endif
    -DUSE_EXTERNAL_YAML=ON \
    -DUSE_EXTERNAL_TINYXML=ON \
    -DUSE_EXTERNAL_LCMS=ON \
    -DUSE_EXTERNAL_SETUPTOOLS=ON
%cmake_build

%install
%cmake_install

# Move documentation to the right location
mkdir -p %{buildroot}%{_docdir}/%{name}
mv %{buildroot}%{_datadir}/doc/OpenColorIO/html/ %{buildroot}%{_docdir}/%{name}/

# Move cmake files to the right location
mkdir -p %{buildroot}%{_datadir}/cmake/Modules
mv %{buildroot}%{_prefix}/*.cmake %{buildroot}%{_prefix}/cmake/*.cmake %{buildroot}%{_datadir}/cmake/Modules/

%post -n libOpenColorIO%{so_ver} -p /sbin/ldconfig
%postun -n libOpenColorIO%{so_ver} -p /sbin/ldconfig

%files
%license LICENSE
%doc ChangeLog README.md
%exclude %{_docdir}/%{name}/html/
%{_bindir}/*
%{_datadir}/ocio/

%files devel
%{_datadir}/cmake/Modules/*
%{_includedir}/OpenColorIO/
%{_libdir}/pkgconfig/OpenColorIO.pc
%{_libdir}/*.so

%files doc
%{_docdir}/%{name}/html/

%files -n libOpenColorIO%{so_ver}
%{_libdir}/libOpenColorIO.so.%{so_ver}*

%files -n python-OpenColorIO
%{python3_sitearch}/PyOpenColorIO.so

%files -n python-OpenColorIO-devel
%{_includedir}/PyOpenColorIO/

%changelog
* Thu Jul  1 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update Requires of devel package to python3-devel
* Fri Jan 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Use python3 to produce the package due to python2 removal
* Wed Jan  8 2020 Dave Plater <davejplater@gmail.com>
- Work around yaml-cpp's bad abi versioning by requiring the version
  it was built against. See boo#1160171
* Fri Apr 19 2019 Asterios Dramis <asterios.dramis@gmail.com>
- Update to version 1.1.1:
  * Added optional compatibility for building apps with OpenImageIO
    1.9+
  * Added USE_SSE checks to fix Linux build failure
  * getDisplays() result ordering now matches the active_displays
    config definition or OCIO_ACTIVE_DISPLAYS env var override.
  * Fixed incorrect getDefaultDisplay()/getDefaultView() result
    when OCIO_ACTIVE_DISPLAYS or OCIO_ACTIVE_VIEWS env vars are
    unset.
  * Fixed Windows-specific GetEnv() bug
  * Fixed Windows and MacOS CI failure cases
  * Updated mail list URLs to aswf.io domain
  From version 1.1.0:
  * libc++ build fixes
  * Added support for YAML > 5.0.1
  * YAML and TinyXML patch fixes
  * Clang visibility fix
  * Added write support for Truelight LUTs
  * Improved OCIOYaml
  * Python string corruption fix
  * Added support for CDL
  * Updated documentation
  * Added args/kwargs support to Python MatrixTransform
  * Added description field to Look objects
  * Improved Python 3 compatibility
  * CSP file read fix
  * Added Linux, MacOS, and Windows continuos integration
  * Improved 1D LUT extrapolation
  * Improved 1D LUT negative handling
  * Improved Windows build system
  * Improved cross-platform build system
  * Undefined role crash fix
  * After Effects plugin updated
  * Added reference Photoshop plugin
  * Added reference Docker image
- Added the following patches:
  * OpenColorIO-setuptools.patch (Use external python-setuptools
    for building)
  * 0003-Fix_Linux_compilation.patch
  * 0004-Fix_build_with_GCC-8.patch
  * 0005-Fix_build_with_yaml-cpp0.6.patch
- Added new build requirements libboost_headers-devel and
  python-setuptools.
- Removed support for openSUSE <= 12.2.
* Sat Jan 31 2015 asterios.dramis@gmail.com
- Update to version 1.0.9:
  * CDL cccid supports both named id and index lookups
  * ociobakelut / ocioconvert updates
  * FreeBSD compile dixes
  * FileTransform disk cache allows concurrent disk lookups
  * CSP windows fix
  * Python 3 support
  * Fix envvar abs/relative path testing
  * Can explicitly declare config envvars
  * gcc44 compile warning fixes
- Updated crippled tarball instructions (RegexMatcher.ns2 no longer exists).
- Added new build requirement python-MarkupSafe.
* Sat Jul  6 2013 asterios.dramis@gmail.com
- Use internal yaml-cpp until OpenColorIO is ported to yaml-cpp >= 0.5.0
  currently in Factory.
* Wed May 22 2013 asterios.dramis@gmail.com
- Updated license to "BSD-3-Clause and GPL-2.0+".
- Removed non OSS licensed files from source package - use a crippled tarball
  (bnc#821203).
* Fri Mar 22 2013 asterios.dramis@gmail.com
- Use a proper source URL.
* Thu Mar  7 2013 asterios.dramis@gmail.com
- Build the doc subpackage as noarch.
* Thu Feb 21 2013 asterios.dramis@gmail.com
- Use external yaml-cpp library only for openSUSE > 12.2.
* Thu Feb 21 2013 asterios.dramis@gmail.com
- Initial release (version 1.0.8).
